import { Asset, MoonChain, MOON_CHAINS_CONFIGS } from '../constants';
import { MOONBASE_ASSETS_CONFIGS, MOONBASE_CHAINS_CONFIGS, MOONBASE_CONFIGS, } from './moonbase';
import { MOONBEAM_ASSETS_CONFIGS, MOONBEAM_CHAINS_CONFIGS, MOONBEAM_CONFIGS, } from './moonbeam';
import { MOONRIVER_ASSETS_CONFIGS, MOONRIVER_CHAINS_CONFIGS, MOONRIVER_CONFIGS, } from './moonriver';
export function createConfigGetter(assets, moonAsset, moonChain, chains, configs) {
    return {
        asset: moonAsset,
        assets,
        chain: moonChain,
        deposit: (asset) => {
            const config = configs[asset];
            if (!config) {
                throw new Error(`No config found for asset: ${asset}`);
            }
            return {
                chains: Object.keys(config.deposit).map((chain) => chains[chain]),
                from: (chain) => {
                    const depositConfig = config.deposit[chain];
                    if (!depositConfig) {
                        throw new Error(`No deposit config found for asset: ${asset} and chain: ${chain}`);
                    }
                    return {
                        asset: config.asset,
                        origin: config.origin,
                        config: depositConfig,
                    };
                },
            };
        },
        withdraw: (asset) => {
            const config = configs[asset];
            if (!config) {
                throw new Error(`No config found for asset: ${asset}`);
            }
            return {
                chains: Object.keys(config.withdraw).map((chain) => chains[chain]),
                to: (chain) => {
                    const withdrawConfig = config.withdraw[chain];
                    if (!withdrawConfig) {
                        throw new Error(`No withdraw config found for asset: ${asset} and chain: ${chain}`);
                    }
                    return {
                        asset: config.asset,
                        origin: config.origin,
                        config: withdrawConfig,
                    };
                },
            };
        },
    };
}
export const moonbase = createConfigGetter(MOONBASE_ASSETS_CONFIGS, MOONBASE_ASSETS_CONFIGS[Asset.DEV], MOON_CHAINS_CONFIGS[MoonChain.MoonbaseAlpha], MOONBASE_CHAINS_CONFIGS, MOONBASE_CONFIGS);
export const moonbeam = createConfigGetter(MOONBEAM_ASSETS_CONFIGS, MOONBEAM_ASSETS_CONFIGS[Asset.GLMR], MOON_CHAINS_CONFIGS[MoonChain.Moonbeam], MOONBEAM_CHAINS_CONFIGS, MOONBEAM_CONFIGS);
export const moonriver = createConfigGetter(MOONRIVER_ASSETS_CONFIGS, MOONRIVER_ASSETS_CONFIGS[Asset.MOVR], MOON_CHAINS_CONFIGS[MoonChain.Moonriver], MOONRIVER_CHAINS_CONFIGS, MOONRIVER_CONFIGS);
//# sourceMappingURL=config.js.map